==> knative-model-4.11.1-sources.jar: annotations/io/fabric8/knative/serving/v1/ServiceStatusFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ServiceStatusFluent<A extends io.fabric8.knative.serving.v1.ServiceStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public A withNewAddress(String url);
    public ServiceStatusFluent.AddressNested<A> withNewAddress();
    public ServiceStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public ServiceStatusFluent.AddressNested<A> editAddress();
    public ServiceStatusFluent.AddressNested<A> editOrNewAddress();
    public ServiceStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public ServiceStatusFluent.ConditionsNested<A> addNewCondition();
    public ServiceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public ServiceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public ServiceStatusFluent.ConditionsNested<A> editCondition(int index);
    public ServiceStatusFluent.ConditionsNested<A> editFirstCondition();
    public ServiceStatusFluent.ConditionsNested<A> editLastCondition();
    public ServiceStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public String getLatestCreatedRevisionName();
    public A withLatestCreatedRevisionName(String latestCreatedRevisionName);
    public Boolean hasLatestCreatedRevisionName();
    public A withNewLatestCreatedRevisionName(String arg1);
    public A withNewLatestCreatedRevisionName(StringBuilder arg1);
    public A withNewLatestCreatedRevisionName(StringBuffer arg1);
    public String getLatestReadyRevisionName();
    public A withLatestReadyRevisionName(String latestReadyRevisionName);
    public Boolean hasLatestReadyRevisionName();
    public A withNewLatestReadyRevisionName(String arg1);
    public A withNewLatestReadyRevisionName(StringBuilder arg1);
    public A withNewLatestReadyRevisionName(StringBuffer arg1);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToTraffic(int index,io.fabric8.knative.serving.v1.TrafficTarget item);
    public A setToTraffic(int index,io.fabric8.knative.serving.v1.TrafficTarget item);
    public A addToTraffic(io.fabric8.knative.serving.v1.TrafficTarget... items);
    public A addAllToTraffic(Collection<io.fabric8.knative.serving.v1.TrafficTarget> items);
    public A removeFromTraffic(io.fabric8.knative.serving.v1.TrafficTarget... items);
    public A removeAllFromTraffic(Collection<io.fabric8.knative.serving.v1.TrafficTarget> items);
    public A removeMatchingFromTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1.TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.serving.v1.TrafficTarget> getTraffic();
    public List<io.fabric8.knative.serving.v1.TrafficTarget> buildTraffic();
    public io.fabric8.knative.serving.v1.TrafficTarget buildTraffic(int index);
    public io.fabric8.knative.serving.v1.TrafficTarget buildFirstTraffic();
    public io.fabric8.knative.serving.v1.TrafficTarget buildLastTraffic();
    public io.fabric8.knative.serving.v1.TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1.TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1.TrafficTargetBuilder> predicate);
    public A withTraffic(List<io.fabric8.knative.serving.v1.TrafficTarget> traffic);
    public A withTraffic(io.fabric8.knative.serving.v1.TrafficTarget... traffic);
    public Boolean hasTraffic();
    public ServiceStatusFluent.TrafficNested<A> addNewTraffic();
    public ServiceStatusFluent.TrafficNested<A> addNewTrafficLike(io.fabric8.knative.serving.v1.TrafficTarget item);
    public ServiceStatusFluent.TrafficNested<A> setNewTrafficLike(int index,io.fabric8.knative.serving.v1.TrafficTarget item);
    public ServiceStatusFluent.TrafficNested<A> editTraffic(int index);
    public ServiceStatusFluent.TrafficNested<A> editFirstTraffic();
    public ServiceStatusFluent.TrafficNested<A> editLastTraffic();
    public ServiceStatusFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1.TrafficTargetBuilder> predicate);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(String arg1);
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(StringBuffer arg1);

    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<ServiceStatusFluent.AddressNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<ServiceStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1.TrafficTargetFluent<ServiceStatusFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}


}

==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/serving/v1/ServiceStatusFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ServiceStatusFluent<A extends ServiceStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public A withNewAddress(String url);
    public ServiceStatusFluent.AddressNested<A> withNewAddress();
    public ServiceStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public ServiceStatusFluent.AddressNested<A> editAddress();
    public ServiceStatusFluent.AddressNested<A> editOrNewAddress();
    public ServiceStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToAnnotations(String key,String value);
    public A addToAnnotations(Map<String,String> map);
    public A removeFromAnnotations(String key);
    public A removeFromAnnotations(Map<String,String> map);
    public Map<String,String> getAnnotations();
    public A withAnnotations(Map<String,String> annotations);
    public Boolean hasAnnotations();
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public ServiceStatusFluent.ConditionsNested<A> addNewCondition();
    public ServiceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public ServiceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public ServiceStatusFluent.ConditionsNested<A> editCondition(int index);
    public ServiceStatusFluent.ConditionsNested<A> editFirstCondition();
    public ServiceStatusFluent.ConditionsNested<A> editLastCondition();
    public ServiceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
    public String getLatestCreatedRevisionName();
    public A withLatestCreatedRevisionName(String latestCreatedRevisionName);
    public Boolean hasLatestCreatedRevisionName();
    public A withNewLatestCreatedRevisionName(String arg1);
    public A withNewLatestCreatedRevisionName(StringBuilder arg1);
    public A withNewLatestCreatedRevisionName(StringBuffer arg1);
    public String getLatestReadyRevisionName();
    public A withLatestReadyRevisionName(String latestReadyRevisionName);
    public Boolean hasLatestReadyRevisionName();
    public A withNewLatestReadyRevisionName(String arg1);
    public A withNewLatestReadyRevisionName(StringBuilder arg1);
    public A withNewLatestReadyRevisionName(StringBuffer arg1);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToTraffic(int index,TrafficTarget item);
    public A setToTraffic(int index,TrafficTarget item);
    public A addToTraffic(TrafficTarget... items);
    public A addAllToTraffic(Collection<TrafficTarget> items);
    public A removeFromTraffic(TrafficTarget... items);
    public A removeAllFromTraffic(Collection<TrafficTarget> items);
    public A removeMatchingFromTraffic(Predicate<TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<TrafficTarget> getTraffic();
    public List<TrafficTarget> buildTraffic();
    public TrafficTarget buildTraffic(int index);
    public TrafficTarget buildFirstTraffic();
    public TrafficTarget buildLastTraffic();
    public TrafficTarget buildMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
    public A withTraffic(List<TrafficTarget> traffic);
    public A withTraffic(TrafficTarget... traffic);
    public Boolean hasTraffic();
    public ServiceStatusFluent.TrafficNested<A> addNewTraffic();
    public ServiceStatusFluent.TrafficNested<A> addNewTrafficLike(TrafficTarget item);
    public ServiceStatusFluent.TrafficNested<A> setNewTrafficLike(int index,TrafficTarget item);
    public ServiceStatusFluent.TrafficNested<A> editTraffic(int index);
    public ServiceStatusFluent.TrafficNested<A> editFirstTraffic();
    public ServiceStatusFluent.TrafficNested<A> editLastTraffic();
    public ServiceStatusFluent.TrafficNested<A> editMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(String arg1);
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(StringBuffer arg1);
    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<ServiceStatusFluent.AddressNested<N>> {

            public N and();
            public N endAddress();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<ServiceStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TrafficTargetFluent<ServiceStatusFluent.TrafficNested<N>> {

            public N and();
            public N endTraffic();    }


}
